@@ -39,6 +39,8 @@ public:
     void setTitle(const QString &title);
     void setText(const QString &text);
     void setStyle(OSD::ShowStyle style);
+    static int bubbleWidgetAppBodyHeight();
+    int bubbleWindowAppBodyHeight();
 
 private:
     void refreshTheme();
