@@ -27,7 +27,6 @@
 #define MONITORFULLWIDGET_H
 
 #include <DPlatformWindowHandle>
-#include <DWindowManagerHelper>
 #include <QFrame>
 
 DWIDGET_USE_NAMESPACE
@@ -38,9 +37,20 @@ class MonitorIndicator : public QFrame
 
 public:
     explicit MonitorIndicator(QWidget *parent = 0);
+    ~MonitorIndicator() override;
 
-protected:
-    void resizeEvent(QResizeEvent *e);
+public Q_SLOTS:
+
+    virtual void setVisible(bool visible);
+
+private:
+    void updateGeometry();
+
+private:
+    QFrame *m_topLine;
+    QFrame *m_bottomLine;
+    QFrame *m_leftLine;
+    QFrame *m_rightLine;
 };
 
 #endif // MONITORFULLWIDGET_H
