@@ -1,10 +1,11 @@
-#include <gtest/gtest.h>
-#include <gmock/gmock.h>
-
 #include <QApplication>
 #include <QDebug>
 
-#define private public
+#include <gtest/gtest.h>
+#include <gmock/gmock.h>
+#ifdef QT_DEBUG
+#include <sanitizer/asan_interface.h>
+#endif
 
 int main(int argc, char *argv[])
 {
@@ -15,5 +16,10 @@ int main(int argc, char *argv[])
     ::testing::InitGoogleTest(&argc, argv);
     int ret = RUN_ALL_TESTS();
     qDebug() << "end dde-osd test cases ..............";
+
+#ifdef QT_DEBUG
+    __sanitizer_set_report_path("asan_dde-osd.log");
+#endif
+
     return ret;
 }
